package de.mlessmann.certassist;

import de.mlessmann.certassist.except.UnresolvableCLIDependency;
import org.slf4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.IOException;

import static org.slf4j.LoggerFactory.getLogger;

@Service
public class OpenSSLCertificateCreator {

    private static final Logger LOGGER = getLogger(OpenSSLCertificateCreator.class);

    private final ExecutableResolver executableResolver;

    @Autowired
    public OpenSSLCertificateCreator(ExecutableResolver executableResolver) {
        this.executableResolver = executableResolver;
    }

    public void createCertificate(CertificateRequest request) {
        try {
            String openSSLPath = executableResolver.getOpenSSLPath();

            Process process = new ProcessBuilder()
                    .command(openSSLPath, "--version")
                    .redirectOutput(ProcessBuilder.Redirect.PIPE)
                    .start();
            process.waitFor();
        } catch (IOException | InterruptedException e) {
            LOGGER.atError().log(e.getMessage());
        } catch (UnresolvableCLIDependency e) {
            LOGGER.atError().log(e.getMessage());
        }
    }
}
